import java.util.*;

/**
 * A class to maintain an arbitrarily long list of notes.
 * Notes are numbered for external reference by a human user.
 * In this version, note numbers start at 0.
 * @author David J. Barnes and Michael Kolling, Nicola Asuni
 * @version 2005-11-27
 */
public class Notebook
{
    // Storage for an arbitrary number of notes.
    private ArrayList notes;

    /**
     * Perform any initialization that is required for the
     * notebook.
     */
    public Notebook() {
        notes = new ArrayList();
    }

    /**
     * Store a new note into the notebook.
     * @param note The note to be stored.
     */
    public void storeNote(String note) {
        notes.add(note);
    }

    /**
     * @return The number of notes currently in the notebook.
     */
    public int numberOfNotes() {
        return notes.size();
    }

    /**
     * Show a note.
     * @param noteNumber The number of the note to be shown.
     */
    public void showNote(int noteNumber) {
        if(noteNumber < 0) {
            // This is not a valid note number, so do nothing.
        }
        else if(noteNumber < numberOfNotes()) {
            // This is a valid note number, so we can print it.
            System.out.println(notes.get(noteNumber));
        }
        else {
            // This is not a valid note number, so do nothing.
        }
    }
    
    /**
     * Individua una nota ricercando, all'interno delle note 
     * memorizzate, la prima che inizia con la stringa fornita 
     * come parametro (Utilizzare la documentazione delle classi 
     * String e ArrayList per progettare questo e i succcessivi 
     * metodi); il valore di ritorno indica se la nota è stata 
     * trovata o meno;
     * @author Nicola Asuni
     * @since 2005-11-27
     * 
     * @param target the string (note) to search for
     * @return true if the note has been found, false otherwise
     */
    public boolean showNote(String target) {
        Iterator i = notes.iterator();
        while(i.hasNext()) {
            String currentnote = (String)i.next();
            if (currentnote.startsWith(target)) {
                System.out.println(currentnote);
                return true;
            }
        }
        return false;
    }
    
    /**
     * Rimuove dalla lista la nota che inizia con la stringa 
     * fornita come parametro; il valore di ritorno indica se 
     * la nota è stata eliminata o meno;
     * @author Nicola Asuni
     * @since 2005-11-27
     * 
     * @param target the string (note) to search for
     * @return true if the note has been deleted, false otherwise
     */
    public boolean removeNote(String target) {
        Iterator i = notes.iterator();
        while(i.hasNext()) {
            String currentnote = (String)i.next();
            if (currentnote.startsWith(target)) {
                System.out.println(currentnote);
                i.remove();
                return true;
            }
        }
        return false;
    }
    
    /**
     * Modifica nella lista la nota che inizia con la stringa 
     * fornita come primo parametro e la sostituisce con la stringa 
     * fornita come secondo parametro; il valore di ritorno indica 
     * se la nota è stata modificata o meno;
     * @author Nicola Asuni
     * @since 2005-11-27
     * 
     * @param target The string (note) to be replaced
     * @param replacement The replacement string (note) 
     * @return true if the note has been replaced, false otherwise
     */
    public boolean modifyNote(String target, String replacement) {
        Iterator i = notes.iterator();
        while(i.hasNext()) {
            String currentnote = (String)i.next();
            if (currentnote.startsWith(target)) {
                System.out.println("target:" + currentnote);
                System.out.println("replacement:" + replacement);
                notes.set(notes.indexOf(currentnote), replacement); 
                return true;
            }
        }
        return false;
    }
    
    /**
     * Ordina le note in ordine alfabetico.
     * @author Nicola Asuni
     * @since 2005-11-27
     */
    public void sortNotes() {
        Collections.sort(notes);
    }

}
